==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiWidgets/QPlainTextEdit_shell.h <==
#ifndef QPLAINTEXTEDIT_SHELL_H
#define QPLAINTEXTEDIT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtwidgets-config.h>
#if QT_CONFIG(textedit)
#include <QtWidgets/qplaintextedit.h>
#endif //QT_CONFIG(textedit)
#include <QtJambi/QtJambiAPI>
#include <QAbstractTextDocumentLayout>
#include <QTextEdit>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qlocale.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qmimedata.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qrect.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtGui/qbackingstore.h>
#include <QtGui/qbitmap.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qfont.h>
#include <QtGui/qfontinfo.h>
#include <QtGui/qfontmetrics.h>
#include <QtGui/qicon.h>
#include <QtGui/qkeysequence.h>
#include <QtGui/qpagedpaintdevice.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpalette.h>
#include <QtGui/qpixmap.h>
#include <QtGui/qregion.h>
#include <QtGui/qscreen.h>
#include <QtGui/qtextcursor.h>
#include <QtGui/qtextdocument.h>
#include <QtGui/qtextformat.h>
#include <QtGui/qtextobject.h>
#include <QtGui/qtextoption.h>
#include <QtGui/qwindow.h>
#include <QtWidgets/qabstractscrollarea.h>
#include <QtWidgets/qaction.h>
#include <QtWidgets/qframe.h>
#if QT_CONFIG(graphicseffect)
#include <QtWidgets/qgraphicseffect.h>
#endif //QT_CONFIG(graphicseffect)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsproxywidget.h>
#endif //QT_CONFIG(graphicsview)
#include <QtWidgets/qlayout.h>
#if QT_CONFIG(menu)
#include <QtWidgets/qmenu.h>
#endif //QT_CONFIG(menu)
#if QT_CONFIG(scrollbar)
#include <QtWidgets/qscrollbar.h>
#endif //QT_CONFIG(scrollbar)
#include <QtWidgets/qsizepolicy.h>
#include <QtWidgets/qstyle.h>
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/AboutToPaint>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(textedit)

class QPlainTextEdit_shell : public QPlainTextEdit, public QtJambiShellInterface
{
public:
    QPlainTextEdit_shell(const QString& text0, QWidget* parent1 = nullptr);
    QPlainTextEdit_shell(QWidget* parent0 = nullptr);
    ~QPlainTextEdit_shell() override;

    void actionEvent(QActionEvent* event0) override;
    bool canInsertFromMimeData(const QMimeData* source0) const override;
    void changeEvent(QEvent* e0) override;
    void childEvent(QChildEvent* event0) override;
    void closeEvent(QCloseEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void contextMenuEvent(QContextMenuEvent* e0) override;
    QMimeData* createMimeDataFromSelection() const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void doSetTextCursor(const QTextCursor& cursor0) override;
    void dragEnterEvent(QDragEnterEvent* e0) override;
    void dragLeaveEvent(QDragLeaveEvent* e0) override;
    void dragMoveEvent(QDragMoveEvent* e0) override;
    void dropEvent(QDropEvent* e0) override;
    void enterEvent(QEvent* event0) override;
    bool event(QEvent* e0) override;
    bool eventFilter(QObject* arg__1, QEvent* arg__2) override;
    void focusInEvent(QFocusEvent* e0) override;
    bool focusNextPrevChild(bool next0) override;
    void focusOutEvent(QFocusEvent* e0) override;
    bool hasHeightForWidth() const override;
    int heightForWidth(int arg__1) const override;
    void hideEvent(QHideEvent* event0) override;
    void initPainter(QPainter* painter0) const override;
    void inputMethodEvent(QInputMethodEvent* arg__1) override;
    QVariant inputMethodQuery(Qt::InputMethodQuery property0) const override;
    void insertFromMimeData(const QMimeData* source0) override;
    void keyPressEvent(QKeyEvent* e0) override;
    void keyReleaseEvent(QKeyEvent* e0) override;
    void leaveEvent(QEvent* event0) override;
    QVariant loadResource(int type0, const QUrl& name1) override;
    int metric(QPaintDevice::PaintDeviceMetric arg__1) const override;
    QSize minimumSizeHint() const override;
    void mouseDoubleClickEvent(QMouseEvent* e0) override;
    void mouseMoveEvent(QMouseEvent* e0) override;
    void mousePressEvent(QMouseEvent* e0) override;
    void mouseReleaseEvent(QMouseEvent* e0) override;
    void moveEvent(QMoveEvent* event0) override;
    QPaintEngine* paintEngine() const override;
    void paintEvent(QPaintEvent* e0) override;
    QPaintDevice* redirected(QPoint* offset0) const override;
    void resizeEvent(QResizeEvent* e0) override;
    void scrollContentsBy(int dx0, int dy1) override;
    void setVisible(bool visible0) override;
    void setupViewport(QWidget* viewport0) override;
    QPainter* sharedPainter() const override;
    void showEvent(QShowEvent* arg__1) override;
    QSize sizeHint() const override;
    void tabletEvent(QTabletEvent* event0) override;
    void timerEvent(QTimerEvent* e0) override;
    bool viewportEvent(QEvent* arg__1) override;
    QSize viewportSizeHint() const override;
    void wheelEvent(QWheelEvent* e0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QPlainTextEdit_access : public QPlainTextEdit
{
    jobject __qt_blockBoundingGeometry_cref_QTextBlock_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID block0) const;
    jobject __qt_blockBoundingRect_cref_QTextBlock_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID block0) const;
    jobject __qt_contentOffset_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_firstVisibleBlock_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_getPaintContext_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_zoomInF_float(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jfloat range0);
    jboolean __qt_canInsertFromMimeData_const_QMimeData_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID source0) const;
    void __qt_changeEvent_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    void __qt_contextMenuEvent_QContextMenuEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    jobject __qt_createMimeDataFromSelection_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_doSetTextCursor_cref_QTextCursor(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID cursor0);
    void __qt_dragEnterEvent_QDragEnterEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    void __qt_dragLeaveEvent_QDragLeaveEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    void __qt_dragMoveEvent_QDragMoveEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    void __qt_dropEvent_QDropEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    jboolean __qt_event_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    void __qt_focusInEvent_QFocusEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    jboolean __qt_focusNextPrevChild_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean next0);
    void __qt_focusOutEvent_QFocusEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    void __qt_inputMethodEvent_QInputMethodEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    jobject __qt_inputMethodQuery_Qt_InputMethodQuery_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint property0) const;
    void __qt_insertFromMimeData_const_QMimeData_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID source0);
    void __qt_keyPressEvent_QKeyEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    void __qt_keyReleaseEvent_QKeyEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    jobject __qt_loadResource_int_cref_QUrl(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint type0, QtJambiNativeID name1);
    void __qt_mouseDoubleClickEvent_QMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    void __qt_mouseMoveEvent_QMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    void __qt_mousePressEvent_QMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    void __qt_mouseReleaseEvent_QMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    void __qt_paintEvent_QPaintEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    void __qt_resizeEvent_QResizeEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    void __qt_scrollContentsBy_int_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint dx0, jint dy1);
    void __qt_showEvent_QShowEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_timerEvent_QTimerEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    void __qt_wheelEvent_QWheelEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
};

#endif // QT_CONFIG(textedit)
#endif // QPLAINTEXTEDIT_SHELL_H

==> qtjambi-debuginfo-macos-6.7.2.jar: sources/QtJambiWidgets/QPlainTextEdit_shell.h <==
#ifndef QPLAINTEXTEDIT_SHELL_H
#define QPLAINTEXTEDIT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtwidgets-config.h>
#if QT_CONFIG(textedit)
#include <QtWidgets/qplaintextedit.h>
#endif //QT_CONFIG(textedit)
#include <QtJambi/QtJambiAPI>
#include <QAbstractTextDocumentLayout>
#include <QTextEdit>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qlocale.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qmimedata.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtGui/qtguiglobal.h>
#if QT_CONFIG(action)
#include <QtGui/qaction.h>
#endif //QT_CONFIG(action)
#include <QtGui/qbackingstore.h>
#include <QtGui/qbitmap.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qfont.h>
#include <QtGui/qfontinfo.h>
#include <QtGui/qfontmetrics.h>
#include <QtGui/qicon.h>
#if QT_CONFIG(shortcut)
#include <QtGui/qkeysequence.h>
#endif //QT_CONFIG(shortcut)
#include <QtGui/qpagedpaintdevice.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpalette.h>
#include <QtGui/qpixmap.h>
#include <QtGui/qregion.h>
#include <QtGui/qscreen.h>
#include <QtGui/qtextcursor.h>
#include <QtGui/qtextdocument.h>
#include <QtGui/qtextformat.h>
#include <QtGui/qtextobject.h>
#include <QtGui/qtextoption.h>
#include <QtGui/qwindow.h>
#include <QtWidgets/qabstractscrollarea.h>
#include <QtWidgets/qframe.h>
#if QT_CONFIG(graphicseffect)
#include <QtWidgets/qgraphicseffect.h>
#endif //QT_CONFIG(graphicseffect)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsproxywidget.h>
#endif //QT_CONFIG(graphicsview)
#include <QtWidgets/qlayout.h>
#if QT_CONFIG(menu)
#include <QtWidgets/qmenu.h>
#endif //QT_CONFIG(menu)
#if QT_CONFIG(scrollbar)
#include <QtWidgets/qscrollbar.h>
#endif //QT_CONFIG(scrollbar)
#include <QtWidgets/qsizepolicy.h>
#include <QtWidgets/qstyle.h>
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/AboutToPaint>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(textedit)

class QPlainTextEdit_shell : public QPlainTextEdit, public QtJambiShellInterface
{
public:
    QPlainTextEdit_shell(const QString& text0, QWidget* parent1 = nullptr);
    QPlainTextEdit_shell(QWidget* parent0 = nullptr);
    ~QPlainTextEdit_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QPlainTextEdit_mshell;
    friend class QPlainTextEdit_oshell;
};


class QPlainTextEdit_mshell : public QPlainTextEdit_shell
{
public:
    using QPlainTextEdit_shell::QPlainTextEdit_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QPlainTextEdit_oshell : public QPlainTextEdit_mshell
{
public:
    using QPlainTextEdit_mshell::QPlainTextEdit_mshell;
    ~QPlainTextEdit_oshell() override;
    void actionEvent(QActionEvent* event0) override;
    bool canInsertFromMimeData(const QMimeData* source0) const override;
    void changeEvent(QEvent* e0) override;
    void childEvent(QChildEvent* event0) override;
    void closeEvent(QCloseEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void contextMenuEvent(QContextMenuEvent* e0) override;
    QMimeData* createMimeDataFromSelection() const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void doSetTextCursor(const QTextCursor& cursor0) override;
    void dragEnterEvent(QDragEnterEvent* e0) override;
    void dragLeaveEvent(QDragLeaveEvent* e0) override;
    void dragMoveEvent(QDragMoveEvent* e0) override;
    void dropEvent(QDropEvent* e0) override;
    void enterEvent(QEnterEvent* event0) override;
    bool event(QEvent* e0) override;
    bool eventFilter(QObject* arg__1, QEvent* arg__2) override;
    void focusInEvent(QFocusEvent* e0) override;
    bool focusNextPrevChild(bool next0) override;
    void focusOutEvent(QFocusEvent* e0) override;
    bool hasHeightForWidth() const override;
    int heightForWidth(int arg__1) const override;
    void hideEvent(QHideEvent* event0) override;
    void initPainter(QPainter* painter0) const override;
    void initStyleOption(QStyleOptionFrame* option0) const override;
    void inputMethodEvent(QInputMethodEvent* arg__1) override;
    QVariant inputMethodQuery(Qt::InputMethodQuery property0) const override;
    void insertFromMimeData(const QMimeData* source0) override;
    void keyPressEvent(QKeyEvent* e0) override;
    void keyReleaseEvent(QKeyEvent* e0) override;
    void leaveEvent(QEvent* event0) override;
    QVariant loadResource(int type0, const QUrl& name1) override;
    int metric(QPaintDevice::PaintDeviceMetric arg__1) const override;
    QSize minimumSizeHint() const override;
    void mouseDoubleClickEvent(QMouseEvent* e0) override;
    void mouseMoveEvent(QMouseEvent* e0) override;
    void mousePressEvent(QMouseEvent* e0) override;
    void mouseReleaseEvent(QMouseEvent* e0) override;
    void moveEvent(QMoveEvent* event0) override;
    QPaintEngine* paintEngine() const override;
    void paintEvent(QPaintEvent* e0) override;
    QPaintDevice* redirected(QPoint* offset0) const override;
    void resizeEvent(QResizeEvent* e0) override;
    void scrollContentsBy(int dx0, int dy1) override;
    void setVisible(bool visible0) override;
    void setupViewport(QWidget* viewport0) override;
    QPainter* sharedPainter() const override;
    void showEvent(QShowEvent* arg__1) override;
    QSize sizeHint() const override;
    void tabletEvent(QTabletEvent* event0) override;
    void timerEvent(QTimerEvent* e0) override;
    bool viewportEvent(QEvent* arg__1) override;
    QSize viewportSizeHint() const override;
    void wheelEvent(QWheelEvent* e0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QPlainTextEdit_access : public QPlainTextEdit
{
    jobject __qt_blockBoundingGeometry_cref_QTextBlock_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID block0) const;
    jobject __qt_blockBoundingRect_cref_QTextBlock_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID block0) const;
    jobject __qt_contentOffset_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_firstVisibleBlock_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_getPaintContext_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_zoomInF_float(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jfloat range0);
    jboolean __qt_canInsertFromMimeData_const_QMimeData_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID source0) const;
    void __qt_changeEvent_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    void __qt_contextMenuEvent_QContextMenuEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    jobject __qt_createMimeDataFromSelection_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_doSetTextCursor_cref_QTextCursor(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID cursor0);
    void __qt_dragEnterEvent_QDragEnterEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    void __qt_dragLeaveEvent_QDragLeaveEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    void __qt_dragMoveEvent_QDragMoveEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    void __qt_dropEvent_QDropEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    jboolean __qt_event_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    void __qt_focusInEvent_QFocusEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    jboolean __qt_focusNextPrevChild_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean next0);
    void __qt_focusOutEvent_QFocusEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    void __qt_inputMethodEvent_QInputMethodEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    jobject __qt_inputMethodQuery_Qt_InputMethodQuery_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint property0) const;
    void __qt_insertFromMimeData_const_QMimeData_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID source0);
    void __qt_keyPressEvent_QKeyEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    void __qt_keyReleaseEvent_QKeyEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    jobject __qt_loadResource_int_cref_QUrl(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint type0, QtJambiNativeID name1);
    void __qt_mouseDoubleClickEvent_QMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    void __qt_mouseMoveEvent_QMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    void __qt_mousePressEvent_QMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    void __qt_mouseReleaseEvent_QMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    void __qt_paintEvent_QPaintEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    void __qt_resizeEvent_QResizeEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    void __qt_scrollContentsBy_int_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint dx0, jint dy1);
    void __qt_showEvent_QShowEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_timerEvent_QTimerEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    void __qt_wheelEvent_QWheelEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
};

#endif // QT_CONFIG(textedit)
#endif // QPLAINTEXTEDIT_SHELL_H
